﻿using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Repository;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 저장소 항목 스핀 에디터
        /// </summary>
        private RepositoryItemSpinEdit repositoryItemSpinEdit = new RepositoryItemSpinEdit();

        /// <summary>
        /// 저장소 항목 계산기 에디터
        /// </summary>
        private RepositoryItemCalcEdit repositoryItemCalcEdit = new RepositoryItemCalcEdit();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                true                            // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            this.gridView.Columns["UnitPrice"].ShowButtonMode = ShowButtonModeEnum.ShowAlways;

            this.gridView.BestFitColumns();

            this.gridView.CustomRowCellEdit += gridView_CustomRowCellEdit;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 행/셀 편집시 커스텀 처리하기 - gridView_CustomRowCellEdit(sender, e)

        /// <summary>
        /// 그리드 뷰 행/셀 편집시 커스텀 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomRowCellEdit(object sender, CustomRowCellEditEventArgs e)
        {
            GridView gridView = sender as GridView;

            if(e.Column.FieldName == "UnitPrice")
            {
                bool discontinued = (bool)gridView.GetRowCellValue(e.RowHandle, "Discontinued");

                if(discontinued)
                {
                    e.RepositoryItem = this.repositoryItemSpinEdit;
                }
                else
                {
                    e.RepositoryItem = this.repositoryItemCalcEdit;
                }
            }
        }

        #endregion
    }
}